package ArrayData::Sample::DeNiro;

use 5.010001;
use strict;
use warnings;

use Role::Tiny::With;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2024-05-06'; # DATE
our $DIST = 'ArrayDataRoles-Standard'; # DIST
our $VERSION = '0.010'; # VERSION

with 'ArrayDataRole::Source::LinesInDATA';

1;
# ABSTRACT: List of Robert De Niro's movies, in chronological order

=pod

=encoding UTF-8

=head1 NAME

ArrayData::Sample::DeNiro - List of Robert De Niro's movies, in chronological order

=head1 VERSION

This document describes version 0.010 of ArrayData::Sample::DeNiro (from Perl distribution ArrayDataRoles-Standard), released on 2024-05-06.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/ArrayDataRoles-Standard>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-ArrayDataRoles-Standard>.

=head1 SEE ALSO

L<HashData::Sample::DeNiro>

L<TableData::Sample::DeNiro>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2024, 2021 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ArrayDataRoles-Standard>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut

__DATA__
Greetings
Bloody Mama
Hi,Mom!
Born to Win
Mean Streets
Bang the Drum Slowly
The Godfather,Part II
The Last Tycoon
Taxi Driver
1900
New York,New York
The Deer Hunter
Raging Bull
True Confessions
The King of Comedy
Once Upon a Time in America
Falling in Love
Brazil
The Mission
Dear America: Letters Home From Vietnam
The Untouchables
Angel Heart
Midnight Run
Jacknife
We're No Angels
Awakenings
Stanley & Iris
Goodfellas
Cape Fear
Mistress
Guilty by Suspicion
Backdraft
Thunderheart
Night and the City
This Boy's Life
Mad Dog and Glory
A Bronx Tale
Mary Shelley's Frankenstein
Casino
Heat
Sleepers
The Fan
Marvin's Room
Wag the Dog
Jackie Brown
Cop Land
Ronin
Great Expectations
Analyze This
Flawless
The Adventures of Rocky & Bullwinkle
Meet the Parents
Men of Honor
The Score
15 Minutes
City by the Sea
Analyze That
Godsend
Shark Tale
Meet the Fockers
The Bridge of San Luis Rey
Rent
Hide and Seek
The Good Shepherd
Arthur and the Invisibles
Captain Shakespeare
Righteous Kill
What Just Happened?
Everybody's Fine
Machete
Little Fockers
Stone
Killer Elite
New Year's Eve
Limitless
Silver Linings Playbook
Being Flynn
Red Lights
Last Vegas
The Big Wedding
Grudge Match
Killing Season
The Bag Man
Joy
Heist
The Intern
Dirty Grandpa
Hands of Stone
The Comedian
The Wizard of Lies
Joker
The Irishman
The War with Grandpa
The Comeback Trail
Amsterdam
Savage Salvation
Killers of the Flower Moon
About My Father
Ezra
